@@ -38,10 +38,6 @@ pub mod device_calibration;
 pub use self::device_calibration::DeviceCalibration;
 pub mod device_calibration_request;
 pub use self::device_calibration_request::DeviceCalibrationRequest;
-pub mod device_info;
-pub use self::device_info::DeviceInfo;
-pub mod device_info_request;
-pub use self::device_info_request::DeviceInfoRequest;
 pub mod device_request;
 pub use self::device_request::DeviceRequest;
 pub mod email_auth_request;
@@ -130,8 +126,6 @@ pub mod paginated_cloudiot_device_list;
 pub use self::paginated_cloudiot_device_list::PaginatedCloudiotDeviceList;
 pub mod paginated_device_calibration_list;
 pub use self::paginated_device_calibration_list::PaginatedDeviceCalibrationList;
-pub mod paginated_device_info_list;
-pub use self::paginated_device_info_list::PaginatedDeviceInfoList;
 pub mod paginated_device_list;
 pub use self::paginated_device_list::PaginatedDeviceList;
 pub mod paginated_experiment_device_config_list;
@@ -164,6 +158,8 @@ pub mod paginated_remote_command_event_list;
 pub use self::paginated_remote_command_event_list::PaginatedRemoteCommandEventList;
 pub mod paginated_remote_control_command_list;
 pub use self::paginated_remote_control_command_list::PaginatedRemoteControlCommandList;
+pub mod paginated_system_info_list;
+pub use self::paginated_system_info_list::PaginatedSystemInfoList;
 pub mod paginated_task_list;
 pub use self::paginated_task_list::PaginatedTaskList;
 pub mod paginated_task_status_list;
@@ -186,8 +182,6 @@ pub mod patched_cloudiot_device_request;
 pub use self::patched_cloudiot_device_request::PatchedCloudiotDeviceRequest;
 pub mod patched_device_calibration_request;
 pub use self::patched_device_calibration_request::PatchedDeviceCalibrationRequest;
-pub mod patched_device_info_request;
-pub use self::patched_device_info_request::PatchedDeviceInfoRequest;
 pub mod patched_device_request;
 pub use self::patched_device_request::PatchedDeviceRequest;
 pub mod patched_octo_print_device_request;
@@ -200,6 +194,8 @@ pub mod patched_printer_profile_request;
 pub use self::patched_printer_profile_request::PatchedPrinterProfileRequest;
 pub mod patched_remote_control_command_request;
 pub use self::patched_remote_control_command_request::PatchedRemoteControlCommandRequest;
+pub mod patched_system_info_request;
+pub use self::patched_system_info_request::PatchedSystemInfoRequest;
 pub mod patched_user_request;
 pub use self::patched_user_request::PatchedUserRequest;
 pub mod print_job_event;
@@ -252,6 +248,10 @@ pub mod remote_control_command_request;
 pub use self::remote_control_command_request::RemoteControlCommandRequest;
 pub mod software_enum;
 pub use self::software_enum::SoftwareEnum;
+pub mod system_info;
+pub use self::system_info::SystemInfo;
+pub mod system_info_request;
+pub use self::system_info_request::SystemInfoRequest;
 pub mod task;
 pub use self::task::Task;
 pub mod task_request;
